package com.muyu.task.server.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.muyu.common.core.domain.Result;
import com.muyu.common.domian.TaskInfo;
import com.muyu.common.domian.req.TaskInfoAddReq;
import com.muyu.common.domian.req.TaskInfoListReq;
import com.muyu.common.domian.req.TaskInfoUpdReq;
import com.muyu.common.domian.resp.TaskInfoResp;
import com.muyu.task.server.service.TaskInfoService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author Administrator
 */
@RestController
@RequestMapping("taskInfo")
@Tag(name = "任务控制层", description = "进行任务管理查询操作")
public class TaskInfoController {

    @Autowired
    private TaskInfoService taskInfoService;

    /**
     * 获取所有的任务信息
     * @param req
     * @return
     */
    @PostMapping("/list")
    @Operation(summary = "查看任务", description = "根据任务名称 权重 状态 查询")
    public Result<Page<TaskInfoResp>> selectList(@RequestBody TaskInfoListReq req) {
        return Result.success(taskInfoService.selectList(req));
    }

    @PostMapping()
    @Operation(summary = "添加任务", description = "添加任务信息表")
    public Result save(@RequestBody @Validated TaskInfoAddReq req) {
        taskInfoService.save(TaskInfo.addBuild(req));
        return Result.success();
    }

    @GetMapping("/{id}")
    public Result<TaskInfoResp> selectById(@PathVariable("id") Long id) {
        TaskInfo byId = taskInfoService.getById(id);
        return Result.success(TaskInfo.build(byId));
    }

    @DeleteMapping("/{id}")
    public Result delete(@PathVariable("id") Long id) {
        taskInfoService.removeById(id);
        return Result.success(null,"操作成功");
    }

    @PutMapping("/{id}")
    public Result update(@PathVariable("id") Long id , @RequestBody TaskInfoUpdReq req){
        taskInfoService.updateById(TaskInfo.updBuild(req,()->id));
        return Result.success(null,"操作成功");
    }




}
